==> eiffelstudio-16.05.tar: F_code/C135/tr6713.c <==
/*
 * Code for class TREE_KEY [G#1]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "tr6713.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {TREE_KEY}.make */
void F48_1571 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make", 47, Current, 0, 1, 846);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) RTCCL(arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {TREE_KEY}.data */
EIF_REFERENCE F48_1572 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {TREE_KEY}.parent */
EIF_REFERENCE F48_1573 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {TREE_KEY}.is_valid */
EIF_BOOLEAN F48_1574 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("is_valid", 47, Current, 1, 0, 849);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTHOOK(2);
	Result = '\0';
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		tb1 = F34_1386(RTCW(loc1), Current);
		Result = tb1;
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {TREE_KEY}.pos_in_parent */
EIF_INTEGER_32 F48_1575 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("pos_in_parent", 47, Current, 1, 0, 850);
	RTGC;
	RTHOOK(1);
	Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	for (;;) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_2_);
		tr1 = F2554_28496(RTCW(tr1), Result);
		if ((EIF_BOOLEAN)(tr1 == Current)) break;
		RTHOOK(4);
		Result++;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {TREE_KEY}.number */
EIF_INTEGER_32 F48_1576 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("number", 47, Current, 1, 0, 851);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTHOOK(2);
	ti4_1 = F48_1575(Current);
	Result = F34_1385(RTCW(loc1), (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {TREE_KEY}.set_parent */
void F48_1577 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_parent", 47, Current, 0, 1, 852);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {TREE_KEY}.delete */
void F48_1578 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("delete", 47, Current, 1, 0, 853);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTHOOK(2);
	ti4_1 = F48_1575(Current);
	F34_1392(RTCW(loc1), ti4_1);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {TREE_KEY}.add_right */
void F48_1579 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTEAA("add_right", 47, Current, 2, 1, 854);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTHOOK(2);
	tb1 = F34_1383(RTCW(loc1));
	if (tb1) {
		RTHOOK(3);
		ti4_1 = F48_1575(Current);
		F34_1388(RTCW(loc1), arg1, NULL, (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
		ti4_1 = F48_1575(Current);
		loc2 = F2554_28496(RTCW(tr1), (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
		RTHOOK(5);
		F34_1390(RTCW(loc2), arg1);
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

void EIF_Minit6713 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C135/tr6713.c <==
/*
 * Code for class TREE_KEY [G#1]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "tr6713.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {TREE_KEY}.make */
void F144_3262 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 143, Current, 0, 1, 2657);
	RTGC;
	RTHOOK(1);
	tr1 = RTCCL(arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {TREE_KEY}.data */
EIF_REFERENCE F144_3263 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {TREE_KEY}.is_valid */
EIF_BOOLEAN F144_3265 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_valid", 143, Current, 1, 0, 2660);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		tb1 = F137_3206(loc1, Current);
		Result = tb1;
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {TREE_KEY}.pos_in_parent */
EIF_INTEGER_32 F144_3266 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("pos_in_parent", 143, Current, 1, 0, 2661);
	RTGC;
	RTHOOK(1);
	Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	
	for (;;) {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_2_);
		tr1 = F3007_33820(RTCW(tr1), Result);
		if ((EIF_BOOLEAN)(tr1 == Current)) break;
		RTHOOK(5);
		Result++;
		
	}
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {TREE_KEY}.number */
EIF_INTEGER_32 F144_3267 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("number", 143, Current, 1, 0, 2662);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	
	RTHOOK(3);
	ti4_1 = F144_3266(Current);
	Result = F137_3205(RTCW(loc1), (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
}

/* {TREE_KEY}.set_parent */
void F144_3268 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_parent", 143, Current, 0, 1, 2663);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {TREE_KEY}.delete */
void F144_3269 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("delete", 143, Current, 1, 0, 2664);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	
	RTHOOK(3);
	ti4_1 = F144_3266(Current);
	F137_3212(RTCW(loc1), ti4_1);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {TREE_KEY}.add_right */
void F144_3270 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTEAA("add_right", 143, Current, 2, 1, 2665);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	
	RTHOOK(3);
	tb1 = F137_3203(RTCW(loc1));
	if (tb1) {
		RTHOOK(4);
		ti4_1 = F144_3266(Current);
		F137_3208(RTCW(loc1), arg1, NULL, (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
	} else {
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
		ti4_1 = F144_3266(Current);
		loc2 = F3007_33820(RTCW(tr1), (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L)));
		
		RTHOOK(7);
		F137_3210(RTCW(loc2), arg1);
	}
	RTHOOK(8);
	RTLE;
	RTEE;
}

void EIF_Minit6713 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
